@@ -1,6 +1,6 @@
 /*
     libparted
-    Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+    Copyright (C) 1998, 1999, 2000, 2001, 2007 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
+#include <config.h>
 #include <string.h>
 #include <uuid/uuid.h>
 
@@ -123,12 +124,8 @@ fat_probe (PedGeometry* geom, FatType* fat_type)
 
 	if (!fat_boot_sector_read (&fs_info->boot_sector, geom))
 		goto error_free_fs;
-	if (!fat_boot_sector_analyse (&fs_info->boot_sector, fs)) {
-		*fat_type = fat_boot_sector_probe_type (&fs_info->boot_sector,
-							geom);
-		fat_free (fs);
-		return ped_geometry_duplicate (geom);
-	}
+	if (!fat_boot_sector_analyse (&fs_info->boot_sector, fs))
+		goto error_free_fs;
 
 	*fat_type = fs_info->fat_type;
 	result = ped_geometry_new (geom->dev, geom->start,
@@ -194,7 +191,6 @@ static int
 _init_fats (PedFileSystem* fs)
 {
 	FatSpecific*	fs_info = FAT_SPECIFIC (fs);
-	int		i;
 	FatCluster	table_size;
 
 	table_size = fs_info->fat_sectors * 512
